// parsers/geometric.ts
var PGPoint = class PGPointImpl {
  constructor(x, y) {
    this.x = x;
    this.y = y;
  }
  toPostgres() {
    return `(${this.x},${this.y})`;
  }
};
var PGCircle = class PGCircleImpl extends PGPoint {
  constructor(x, y, radius) {
    super(x, y);
    this.radius = radius;
  }
  toPostgres() {
    return `<(${this.x},${this.y}),${this.radius}>`;
  }
};
var INVALID_POINT = new PGPoint(NaN, NaN);
var INVALID_CIRCLE = new PGCircle(NaN, NaN, NaN);
var parsePoint = (value) => {
  if (value[0] !== "(")
    return INVALID_POINT;
  const values = value.substring(1, value.length - 1).split(",");
  return new PGPoint(parseFloat(values[0]), parseFloat(values[1]));
};
var parseCircle = (value) => {
  if (value[0] !== "<" && value[1] !== "(")
    return INVALID_CIRCLE;
  let point = "(";
  let radius = "";
  let pointParsed = false;
  for (let i = 2; i < value.length - 1; i++) {
    if (!pointParsed) {
      point += value[i];
    }
    if (value[i] === ")") {
      pointParsed = true;
      continue;
    } else if (!pointParsed) {
      continue;
    }
    if (value[i] === ",") {
      continue;
    }
    radius += value[i];
  }
  const { x, y } = parsePoint(point);
  return new PGCircle(x, y, parseFloat(radius));
};
export {
  PGCircle,
  PGPoint,
  parseCircle,
  parsePoint
};
//# sourceMappingURL=geometric.mjs.map
