import type { PGParser } from '../parsers';
import type { PGSerialize } from '../serializers';
import type { PGArray } from './array';
/** A parsed PostgreSQL `range` */
export interface PGRange<T> {
    readonly lower: T | null;
    readonly upper: T | null;
    readonly mask: number;
    hasMask(flags: number): boolean;
    isBounded(): boolean;
    isEmpty(): boolean;
    isLowerBoundClosed(): boolean;
    isUpperBoundClosed(): boolean;
    hasLowerBound(): boolean;
    hasUpperBound(): boolean;
    containsPoint(point: T): boolean;
    containsRange(range: PGRange<T>): boolean;
    toPostgres(serialize: PGSerialize): string;
}
/** Constructor (with static constants) for {@link PGRange} */
export interface PGRangeConstructor {
    new <T>(lower: T | null, upper: T | null, flags: number): PGRange<T>;
    readonly RANGE_EMPTY: number;
    readonly RANGE_LB_INC: number;
    readonly RANGE_UB_INC: number;
    readonly RANGE_LB_INF: number;
    readonly RANGE_UB_INF: number;
}
/** A parsed PostgreSQL `range` */
export declare const PGRange: PGRangeConstructor;
/** Parse a PostgreSQL `range` */
export declare function parseRange(value: string): PGRange<string>;
/** Parse a PostgreSQL `range` */
export declare function parseRange<T>(value: string, parser: PGParser<T>): PGRange<T>;
/** Parse a PostgreSQL `range` of _integers_ */
export declare const parseIntRange: PGParser<PGRange<number>>;
/** Parse a PostgreSQL `range` of _floats_ */
export declare const parseFloatRange: PGParser<PGRange<number>>;
/** Parse a PostgreSQL `range` of _big integers_ */
export declare const parseBigintRange: PGParser<PGRange<bigint>>;
/** Parse a PostgreSQL `range` of _timestamps_ */
export declare const parseTimestampRange: PGParser<PGRange<Date>>;
/** Parse a PostgreSQL `range` of _timestamps with time zone_ */
export declare const parseTimestampTzRange: PGParser<PGRange<Date>>;
/** Parse an array of PostgreSQL `range` of _strings_ */
export declare const parseRangeArray: PGParser<PGArray<PGRange<string>>>;
/** Parse an array of PostgreSQL `range` of _integers_ */
export declare const parseIntRangeArray: PGParser<PGArray<PGRange<number>>>;
/** Parse an array of PostgreSQL `range` of _floats_ */
export declare const parseFloatRangeArray: PGParser<PGArray<PGRange<number>>>;
/** Parse an array of PostgreSQL `range` of _big integers_ */
export declare const parseBigintRangeArray: PGParser<PGArray<PGRange<bigint>>>;
/** Parse an array of PostgreSQL `range` of _timestamps_ */
export declare const parseTimestampRangeArray: PGParser<PGArray<PGRange<Date>>>;
/** Parse an array of PostgreSQL `range` of _timestamps with time zone_ */
export declare const parseTimestampTzRangeArray: PGParser<PGArray<PGRange<Date>>>;
