// serializers.ts
import { serializeByteA } from "./serializers/bytea.mjs";
import { serializeDateUTC } from "./serializers/date.mjs";
import { serializeByteA as serializeByteA2 } from "./serializers/bytea.mjs";
import { serializeDateUTC as serializeDateUTC2 } from "./serializers/date.mjs";
var serializationCache = /* @__PURE__ */ new WeakMap();
function quote(string) {
  return `"${string.replace(/\\/g, "\\\\").replace(/"/g, '\\"')}"`;
}
function serializeArray(value, stack) {
  const result = new Array(value.length);
  for (let i = 0; i < value.length; i++) {
    const member = value[i];
    const type = typeof member;
    if (member === null || member === void 0) {
      result[i] = "NULL";
    } else if (type === "boolean") {
      result[i] = member ? "t" : "f";
    } else if (type === "bigint" || type === "number") {
      result[i] = `${member}`;
    } else if (Array.isArray(member)) {
      const cached = serializationCache.get(member);
      if (cached) {
        result[i] = cached;
      } else {
        if (stack.has(member))
          throw new TypeError("Circularity detected serializing");
        stack.add(member);
        result[i] = serializeArray(member, stack);
        serializationCache.set(member, result[i]);
        stack.delete(member);
      }
    } else if (ArrayBuffer.isView(member)) {
      result[i] = `"\\${serializeByteA(member)}"`;
    } else {
      result[i] = quote(serializeValue(member, stack));
    }
  }
  return `{${result.join(",")}}`;
}
function serializeValue(value, stack) {
  if (value === null)
    throw new TypeError('Can not serialize "null"');
  switch (typeof value) {
    case "string":
      return value;
    case "boolean":
      return value ? "t" : "f";
    case "bigint":
    case "number":
      return value.toString();
    case "object":
      break;
    case "function":
    case "symbol":
    case "undefined":
    default:
      throw new TypeError(`Can not serialize "${typeof value}"`);
  }
  const cached = serializationCache.get(value);
  if (cached !== void 0)
    return cached;
  if (stack.has(value))
    throw new TypeError("Circularity detected serializing");
  stack.add(value);
  const subserialize = (v) => serializeValue(v, stack);
  let string;
  if (isPGSerializable(value)) {
    string = value.toPostgres(subserialize);
  } else if (ArrayBuffer.isView(value)) {
    string = serializeByteA(value);
  } else if (Array.isArray(value)) {
    string = serializeArray(value, stack);
  } else if (value instanceof Date) {
    string = serializeDateUTC(value);
  } else {
    string = JSON.stringify(value);
  }
  serializationCache.set(value, string);
  stack.delete(value);
  return string;
}
function isPGSerializable(value) {
  return value && typeof value["toPostgres"] === "function";
}
var serialize = (value) => serializeValue(value, /* @__PURE__ */ new WeakSet());
export {
  serialize,
  serializeByteA2 as serializeByteA,
  serializeDateUTC2 as serializeDateUTC
};
//# sourceMappingURL=serializers.mjs.map
